pub enum BrickletError {
InvalidParameter,
FunctionNotSupported,
UnknownError,
NotConnected,
SuccessButResponseExpectedIsDisabled,
}Expand description
Error type for interactions with Tinkerforge bricks or bricklets.
Variants
InvalidParameter
A parameter was invalid or had an unexpected length
FunctionNotSupported
The brick or bricklet does not support the requested function.
UnknownError
Currently unused
NotConnected
The request can not be fulfulled, as there is currently no connection to a brick daemon.
SuccessButResponseExpectedIsDisabled
The request was sent, but response expected is disabled, so no response can be received. This is not an error.