logo
pub enum BrickletRecvTimeoutError {
    QueueDisconnected,
    QueueTimeout,
    InvalidParameter,
    FunctionNotSupported,
    UnknownError,
    MalformedPacket,
    NotConnected,
    SuccessButResponseExpectedIsDisabled,
}
Error type which is returned if a ConvertingReceiver::recv call fails.

Variants

QueueDisconnected

The queue was disconnected. This usually happens if the ip connection is destroyed.

QueueTimeout

The request could not be responded to before the timeout was reached.

InvalidParameter

A parameter was invalid or had an unexpected length.

FunctionNotSupported

The brick or bricklet does not support the requested function.

UnknownError

Currently unused

MalformedPacket

The received packet had an unexpected length. Maybe a function was called on a wrong brick or bricklet?

NotConnected

The request can not be fulfulled, as there is currently no connection to a brick daemon.

SuccessButResponseExpectedIsDisabled

The request was sent, but response expected is disabled, so no response can be received. This is not an error.