[][src]Struct tinkerforge::hall_effect_bricklet::HallEffectBricklet

pub struct HallEffectBricklet { /* fields omitted */ }

Detects presence of magnetic field

Methods

impl HallEffectBricklet[src]

pub const DEVICE_IDENTIFIER: u16[src]

pub const DEVICE_DISPLAY_NAME: &'static str[src]

pub fn new<T: GetRequestSender>(uid: &str, req_sender: T) -> HallEffectBricklet[src]

Creates an object with the unique device ID uid. This object can then be used after the IP Connection ip_connection is connected.

pub fn get_response_expected(
    &mut self,
    fun: HallEffectBrickletFunction
) -> Result<bool, GetResponseExpectedError>
[src]

Returns the response expected flag for the function specified by the function ID parameter. It is true if the function is expected to send a response, false otherwise.

For getter functions this is enabled by default and cannot be disabled, because those functions will always send a response. For callback configuration functions it is enabled by default too, but can be disabled by set_response_expected. For setter functions it is disabled by default and can be enabled.

Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is send and errors are silently ignored, because they cannot be detected.

See set_response_expected for the list of function ID constants available for this function.

pub fn set_response_expected(
    &mut self,
    fun: HallEffectBrickletFunction,
    response_expected: bool
) -> Result<(), SetResponseExpectedError>
[src]

Changes the response expected flag of the function specified by the function ID parameter. This flag can only be changed for setter (default value: false) and callback configuration functions (default value: true). For getter functions it is always enabled.

Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is send and errors are silently ignored, because they cannot be detected.

pub fn set_response_expected_all(&mut self, response_expected: bool)[src]

Changes the response expected flag for all setter and callback configuration functions of this device at once.

pub fn get_api_version(&self) -> [u8; 3][src]

Returns the version of the API definition (major, minor, revision) implemented by this API bindings. This is neither the release version of this API bindings nor does it tell you anything about the represented Brick or Bricklet.

pub fn get_edge_count_callback_receiver(
    &self
) -> ConvertingCallbackReceiver<EdgeCountEvent>
[src]

This receiver is triggered periodically with the period that is set by set_edge_count_callback_period. The parameters are the current count and the current value (see get_value and get_edge_count).

The get_edge_count_callback_receiver receiver is only triggered if the count or value changed since the last triggering.

pub fn get_value(&self) -> ConvertingReceiver<bool>[src]

Returns true if a magnetic field of 35 Gauss (3.5mT) or greater is detected.

pub fn get_edge_count(&self, reset_counter: bool) -> ConvertingReceiver<u32>[src]

Returns the current value of the edge counter. You can configure edge type (rising, falling, both) that is counted with set_edge_count_config.

If you set the reset counter to true, the count is set back to 0 directly after it is read.

pub fn set_edge_count_config(
    &self,
    edge_type: u8,
    debounce: u8
) -> ConvertingReceiver<()>
[src]

The edge type parameter configures if rising edges, falling edges or both are counted. Possible edge types are:

  • 0 = rising (default)
  • 1 = falling
  • 2 = both

A magnetic field of 35 Gauss (3.5mT) or greater causes a falling edge and a magnetic field of 25 Gauss (2.5mT) or smaller causes a rising edge.

If a magnet comes near the Bricklet the signal goes low (falling edge), if a magnet is removed from the vicinity the signal goes high (rising edge).

The debounce time is given in ms.

Configuring an edge counter resets its value to 0.

If you don't know what any of this means, just leave it at default. The default configuration is very likely OK for you.

Default values: 0 (edge type) and 100ms (debounce time)

Associated constants:

  • HALL_EFFECT_BRICKLET_EDGE_TYPE_RISING
  • HALL_EFFECT_BRICKLET_EDGE_TYPE_FALLING
  • HALL_EFFECT_BRICKLET_EDGE_TYPE_BOTH

pub fn get_edge_count_config(&self) -> ConvertingReceiver<EdgeCountConfig>[src]

Returns the edge type and debounce time as set by set_edge_count_config.

Associated constants:

  • HALL_EFFECT_BRICKLET_EDGE_TYPE_RISING
  • HALL_EFFECT_BRICKLET_EDGE_TYPE_FALLING
  • HALL_EFFECT_BRICKLET_EDGE_TYPE_BOTH

pub fn set_edge_interrupt(&self, edges: u32) -> ConvertingReceiver<()>[src]

Sets the number of edges until an interrupt is invoked.

If edges is set to n, an interrupt is invoked for every n-th detected edge.

If edges is set to 0, the interrupt is disabled.

Default value is 0.

pub fn get_edge_interrupt(&self) -> ConvertingReceiver<u32>[src]

Returns the edges as set by set_edge_interrupt.

pub fn set_edge_count_callback_period(
    &self,
    period: u32
) -> ConvertingReceiver<()>
[src]

Sets the period in ms with which the get_edge_count_callback_receiver receiver is triggered periodically. A value of 0 turns the receiver off.

The get_edge_count_callback_receiver receiver is only triggered if the edge count has changed since the last triggering.

The default value is 0.

pub fn get_edge_count_callback_period(&self) -> ConvertingReceiver<u32>[src]

Returns the period as set by set_edge_count_callback_period.

pub fn edge_interrupt(&self) -> ConvertingReceiver<EdgeInterrupt>[src]

This receiver is triggered every n-th count, as configured with set_edge_interrupt. The parameters are the current count and the current value (see get_value and get_edge_count).

pub fn get_identity(&self) -> ConvertingReceiver<Identity>[src]

Returns the UID, the UID where the Bricklet is connected to, the position, the hardware and firmware version as well as the device identifier.

The position can be 'a', 'b', 'c' or 'd'.

The device identifier numbers can be found here. |device_identifier_constant|