pub struct VoltagesCallbackConfiguration {
pub period: u32,
pub value_has_to_change: bool,
}Fields
period: u32value_has_to_change: boolTrait Implementations
Sourceimpl Clone for VoltagesCallbackConfiguration
impl Clone for VoltagesCallbackConfiguration
Sourcefn clone(&self) -> VoltagesCallbackConfiguration
fn clone(&self) -> VoltagesCallbackConfiguration
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for VoltagesCallbackConfiguration
impl Default for VoltagesCallbackConfiguration
Sourcefn default() -> VoltagesCallbackConfiguration
fn default() -> VoltagesCallbackConfiguration
Returns the “default value” for a type. Read more
Sourceimpl FromByteSlice for VoltagesCallbackConfiguration
impl FromByteSlice for VoltagesCallbackConfiguration
Sourcefn bytes_expected() -> usize
fn bytes_expected() -> usize
Returns how many bytes are expected to deserialize a instance of the implementing type. Currently this method is only used for strings.
Sourcefn from_le_byte_slice(bytes: &[u8]) -> VoltagesCallbackConfiguration
fn from_le_byte_slice(bytes: &[u8]) -> VoltagesCallbackConfiguration
Deserialize the implementing type from a byte slice.
Sourceimpl Hash for VoltagesCallbackConfiguration
impl Hash for VoltagesCallbackConfiguration
Sourceimpl PartialEq for VoltagesCallbackConfiguration
impl PartialEq for VoltagesCallbackConfiguration
Sourcefn eq(&self, other: &VoltagesCallbackConfiguration) -> bool
fn eq(&self, other: &VoltagesCallbackConfiguration) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for VoltagesCallbackConfiguration
impl Eq for VoltagesCallbackConfiguration
impl StructuralPartialEq for VoltagesCallbackConfiguration