pub struct StackVoltageCallbackThreshold {
pub option: char,
pub min: u16,
pub max: u16,
}Fields
option: charmin: u16max: u16Trait Implementations
Sourceimpl Clone for StackVoltageCallbackThreshold
impl Clone for StackVoltageCallbackThreshold
Sourcefn clone(&self) -> StackVoltageCallbackThreshold
fn clone(&self) -> StackVoltageCallbackThreshold
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for StackVoltageCallbackThreshold
impl Default for StackVoltageCallbackThreshold
Sourcefn default() -> StackVoltageCallbackThreshold
fn default() -> StackVoltageCallbackThreshold
Returns the “default value” for a type. Read more
Sourceimpl FromByteSlice for StackVoltageCallbackThreshold
impl FromByteSlice for StackVoltageCallbackThreshold
Sourcefn bytes_expected() -> usize
fn bytes_expected() -> usize
Returns how many bytes are expected to deserialize a instance of the implementing type. Currently this method is only used for strings.
Sourcefn from_le_byte_slice(bytes: &[u8]) -> StackVoltageCallbackThreshold
fn from_le_byte_slice(bytes: &[u8]) -> StackVoltageCallbackThreshold
Deserialize the implementing type from a byte slice.
Sourceimpl Hash for StackVoltageCallbackThreshold
impl Hash for StackVoltageCallbackThreshold
Sourceimpl PartialEq for StackVoltageCallbackThreshold
impl PartialEq for StackVoltageCallbackThreshold
Sourcefn eq(&self, other: &StackVoltageCallbackThreshold) -> bool
fn eq(&self, other: &StackVoltageCallbackThreshold) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for StackVoltageCallbackThreshold
impl Eq for StackVoltageCallbackThreshold
impl StructuralPartialEq for StackVoltageCallbackThreshold