[−][src]Module tinkerforge::stepper_brick
Drives one bipolar stepper motor with up to 38V and 2.5A per phase.
See also the documentation here.
Structs
| AllData | |
| AllDataEvent | |
| Identity | |
| NewStateEvent | |
| Protocol1BrickletName | |
| SpeedRamping | |
| SpitfpBaudrateConfig | |
| SpitfpErrorCount | |
| StepperBrick | Drives one bipolar stepper motor with up to 38V and 2.5A per phase |
Enums
| StepperBrickFunction |