Struct tinkerforge::temperature_bricklet::TemperatureBricklet [−][src]
pub struct TemperatureBricklet { /* fields omitted */ }Expand description
Measures ambient temperature with 0.5°C accuracy
Implementations
impl TemperatureBricklet[src]
impl TemperatureBricklet[src]pub const DEVICE_IDENTIFIER: u16[src]
pub const DEVICE_DISPLAY_NAME: &'static str[src]
pub fn new<T: GetRequestSender>(uid: &str, req_sender: T) -> TemperatureBricklet[src]
pub fn new<T: GetRequestSender>(uid: &str, req_sender: T) -> TemperatureBricklet[src]Creates an object with the unique device ID uid. This object can then be used after the IP Connection ip_connection is connected.
pub fn get_response_expected(
&mut self,
fun: TemperatureBrickletFunction
) -> Result<bool, GetResponseExpectedError>[src]
pub fn get_response_expected(
&mut self,
fun: TemperatureBrickletFunction
) -> Result<bool, GetResponseExpectedError>[src]Returns the response expected flag for the function specified by the function ID parameter. It is true if the function is expected to send a response, false otherwise.
For getter functions this is enabled by default and cannot be disabled, because those
functions will always send a response. For callback configuration functions it is enabled
by default too, but can be disabled by set_response_expected.
For setter functions it is disabled by default and can be enabled.
Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is sent and errors are silently ignored, because they cannot be detected.
See set_response_expected for the list of function ID constants available for this function.
pub fn set_response_expected(
&mut self,
fun: TemperatureBrickletFunction,
response_expected: bool
) -> Result<(), SetResponseExpectedError>[src]
pub fn set_response_expected(
&mut self,
fun: TemperatureBrickletFunction,
response_expected: bool
) -> Result<(), SetResponseExpectedError>[src]Changes the response expected flag of the function specified by the function ID parameter. This flag can only be changed for setter (default value: false) and callback configuration functions (default value: true). For getter functions it is always enabled.
Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is sent and errors are silently ignored, because they cannot be detected.
pub fn set_response_expected_all(&mut self, response_expected: bool)[src]
pub fn set_response_expected_all(&mut self, response_expected: bool)[src]Changes the response expected flag for all setter and callback configuration functions of this device at once.
pub fn get_api_version(&self) -> [u8; 3][src]
pub fn get_api_version(&self) -> [u8; 3][src]Returns the version of the API definition (major, minor, revision) implemented by this API bindings. This is neither the release version of this API bindings nor does it tell you anything about the represented Brick or Bricklet.
pub fn get_temperature_callback_receiver(
&self
) -> ConvertingCallbackReceiver<i16>[src]
pub fn get_temperature_callback_receiver(
&self
) -> ConvertingCallbackReceiver<i16>[src]This receiver is triggered periodically with the period that is set by
set_temperature_callback_period. The parameter is the
temperature of the sensor.
The get_temperature_callback_receiver receiver is only triggered if the temperature has changed
since the last triggering.
pub fn get_temperature_reached_callback_receiver(
&self
) -> ConvertingCallbackReceiver<i16>[src]
pub fn get_temperature_reached_callback_receiver(
&self
) -> ConvertingCallbackReceiver<i16>[src]This receiver is triggered when the threshold as set by
[set_temperature_callback_threshold] is reached.
The parameter is the temperature of the sensor.
If the threshold keeps being reached, the receiver is triggered periodically
with the period as set by [set_debounce_period].
pub fn get_temperature(&self) -> ConvertingReceiver<i16>[src]
pub fn get_temperature(&self) -> ConvertingReceiver<i16>[src]Returns the temperature of the sensor.
If you want to get the temperature periodically, it is recommended
to use the [get_temperature_callback_receiver] receiver and set the period with
[set_temperature_callback_period].
pub fn set_temperature_callback_period(
&self,
period: u32
) -> ConvertingReceiver<()>[src]
pub fn set_temperature_callback_period(
&self,
period: u32
) -> ConvertingReceiver<()>[src]Sets the period with which the [get_temperature_callback_receiver] receiver is triggered
periodically. A value of 0 turns the receiver off.
The [get_temperature_callback_receiver] receiver is only triggered if the temperature has changed
since the last triggering.
pub fn get_temperature_callback_period(&self) -> ConvertingReceiver<u32>[src]
pub fn get_temperature_callback_period(&self) -> ConvertingReceiver<u32>[src]Returns the period as set by [set_temperature_callback_period].
pub fn set_temperature_callback_threshold(
&self,
option: char,
min: i16,
max: i16
) -> ConvertingReceiver<()>[src]
pub fn set_temperature_callback_threshold(
&self,
option: char,
min: i16,
max: i16
) -> ConvertingReceiver<()>[src]Sets the thresholds for the [get_temperature_reached_callback_receiver] receiver.
The following options are possible:
| Option | Description |
|---|---|
| ‘x’ | Receiver is turned off |
| ‘o’ | Receiver is triggered when the temperature is outside the min and max values |
| ‘i’ | Receiver is triggered when the temperature is inside the min and max values |
| ‘<’ | Receiver is triggered when the temperature is smaller than the min value (max is ignored) |
| ‘>’ | Receiver is triggered when the temperature is greater than the min value (max is ignored) |
Associated constants:
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_OFF
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_OUTSIDE
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_INSIDE
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_SMALLER
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_GREATER
pub fn get_temperature_callback_threshold(
&self
) -> ConvertingReceiver<TemperatureCallbackThreshold>[src]
pub fn get_temperature_callback_threshold(
&self
) -> ConvertingReceiver<TemperatureCallbackThreshold>[src]Returns the threshold as set by [set_temperature_callback_threshold].
Associated constants:
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_OFF
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_OUTSIDE
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_INSIDE
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_SMALLER
- TEMPERATURE_BRICKLET_THRESHOLD_OPTION_GREATER
pub fn set_debounce_period(&self, debounce: u32) -> ConvertingReceiver<()>[src]
pub fn set_debounce_period(&self, debounce: u32) -> ConvertingReceiver<()>[src]Sets the period with which the threshold receiver
- [
get_temperature_reached_callback_receiver]
is triggered, if the threshold
- [
set_temperature_callback_threshold]
keeps being reached.
pub fn get_debounce_period(&self) -> ConvertingReceiver<u32>[src]
pub fn get_debounce_period(&self) -> ConvertingReceiver<u32>[src]Returns the debounce period as set by [set_debounce_period].
pub fn set_i2c_mode(&self, mode: u8) -> ConvertingReceiver<()>[src]
pub fn set_i2c_mode(&self, mode: u8) -> ConvertingReceiver<()>[src]Sets the I2C mode. Possible modes are:
- 0: Fast (400kHz)
- 1: Slow (100kHz)
If you have problems with obvious outliers in the Temperature Bricklet measurements, they may be caused by EMI issues. In this case it may be helpful to lower the I2C speed.
It is however not recommended to lower the I2C speed in applications where a high throughput needs to be achieved.
.. versionadded:: 2.0.1$nbsp;(Plugin)
Associated constants:
- TEMPERATURE_BRICKLET_I2C_MODE_FAST
- TEMPERATURE_BRICKLET_I2C_MODE_SLOW
pub fn get_i2c_mode(&self) -> ConvertingReceiver<u8>[src]
pub fn get_i2c_mode(&self) -> ConvertingReceiver<u8>[src]Returns the I2C mode as set by [set_i2c_mode].
.. versionadded:: 2.0.1$nbsp;(Plugin)
Associated constants:
- TEMPERATURE_BRICKLET_I2C_MODE_FAST
- TEMPERATURE_BRICKLET_I2C_MODE_SLOW
pub fn get_identity(&self) -> ConvertingReceiver<Identity>[src]
pub fn get_identity(&self) -> ConvertingReceiver<Identity>[src]Returns the UID, the UID where the Bricklet is connected to, the position, the hardware and firmware version as well as the device identifier.
The position can be ‘a’, ‘b’, ‘c’, ‘d’, ‘e’, ‘f’, ‘g’ or ‘h’ (Bricklet Port). A Bricklet connected to an Isolator Bricklet is always at position ‘z’.
The device identifier numbers can be found here. |device_identifier_constant|