pub struct RemoteSwitchBricklet { /* private fields */ }Expand description
Controls remote mains switches
Implementations
sourceimpl RemoteSwitchBricklet
impl RemoteSwitchBricklet
pub const DEVICE_IDENTIFIER: u16 = 235u16
pub const DEVICE_DISPLAY_NAME: &'static str = "Remote Switch Bricklet"
sourcepub fn new<T: GetRequestSender>(
uid: &str,
req_sender: T
) -> RemoteSwitchBricklet
pub fn new<T: GetRequestSender>(
uid: &str,
req_sender: T
) -> RemoteSwitchBricklet
Creates an object with the unique device ID uid. This object can then be used after the IP Connection ip_connection is connected.
sourcepub fn get_response_expected(
&mut self,
fun: RemoteSwitchBrickletFunction
) -> Result<bool, GetResponseExpectedError>
pub fn get_response_expected(
&mut self,
fun: RemoteSwitchBrickletFunction
) -> Result<bool, GetResponseExpectedError>
Returns the response expected flag for the function specified by the function ID parameter. It is true if the function is expected to send a response, false otherwise.
For getter functions this is enabled by default and cannot be disabled, because those
functions will always send a response. For callback configuration functions it is enabled
by default too, but can be disabled by set_response_expected.
For setter functions it is disabled by default and can be enabled.
Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is sent and errors are silently ignored, because they cannot be detected.
See set_response_expected for the list of function ID constants available for this function.
sourcepub fn set_response_expected(
&mut self,
fun: RemoteSwitchBrickletFunction,
response_expected: bool
) -> Result<(), SetResponseExpectedError>
pub fn set_response_expected(
&mut self,
fun: RemoteSwitchBrickletFunction,
response_expected: bool
) -> Result<(), SetResponseExpectedError>
Changes the response expected flag of the function specified by the function ID parameter. This flag can only be changed for setter (default value: false) and callback configuration functions (default value: true). For getter functions it is always enabled.
Enabling the response expected flag for a setter function allows to detect timeouts and other error conditions calls of this setter as well. The device will then send a response for this purpose. If this flag is disabled for a setter function then no response is sent and errors are silently ignored, because they cannot be detected.
sourcepub fn set_response_expected_all(&mut self, response_expected: bool)
pub fn set_response_expected_all(&mut self, response_expected: bool)
Changes the response expected flag for all setter and callback configuration functions of this device at once.
sourcepub fn get_api_version(&self) -> [u8; 3]
pub fn get_api_version(&self) -> [u8; 3]
Returns the version of the API definition (major, minor, revision) implemented by this API bindings. This is neither the release version of this API bindings nor does it tell you anything about the represented Brick or Bricklet.
sourcepub fn get_switching_done_callback_receiver(
&self
) -> ConvertingCallbackReceiver<()>
pub fn get_switching_done_callback_receiver(
&self
) -> ConvertingCallbackReceiver<()>
This receiver is triggered whenever the switching state changes
from busy to ready, see get_switching_state.
sourcepub fn switch_socket(
&self,
house_code: u8,
receiver_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
pub fn switch_socket(
&self,
house_code: u8,
receiver_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
This function is deprecated, use [switch_socket_a] instead.
Associated constants:
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_OFF
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_ON
sourcepub fn get_switching_state(&self) -> ConvertingReceiver<u8>
pub fn get_switching_state(&self) -> ConvertingReceiver<u8>
Returns the current switching state. If the current state is busy, the Bricklet is currently sending a code to switch a socket. It will not accept any requests to switch sockets until the state changes to ready.
How long the switching takes is dependent on the number of repeats, see
[set_repeats].
Associated constants:
- REMOTE_SWITCH_BRICKLET_SWITCHING_STATE_READY
- REMOTE_SWITCH_BRICKLET_SWITCHING_STATE_BUSY
sourcepub fn set_repeats(&self, repeats: u8) -> ConvertingReceiver<()>
pub fn set_repeats(&self, repeats: u8) -> ConvertingReceiver<()>
Sets the number of times the code is sent when one of the switch socket functions is called. The repeats basically correspond to the amount of time that a button of the remote is pressed.
Some dimmers are controlled by the length of a button pressed, this can be simulated by increasing the repeats.
sourcepub fn get_repeats(&self) -> ConvertingReceiver<u8>
pub fn get_repeats(&self) -> ConvertingReceiver<u8>
Returns the number of repeats as set by [set_repeats].
sourcepub fn switch_socket_a(
&self,
house_code: u8,
receiver_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
pub fn switch_socket_a(
&self,
house_code: u8,
receiver_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
To switch a type A socket you have to give the house code, receiver code and the state (on or off) you want to switch to.
A detailed description on how you can figure out the house and receiver code can be found here.
.. versionadded:: 2.0.1$nbsp;(Plugin)
Associated constants:
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_OFF
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_ON
sourcepub fn switch_socket_b(
&self,
address: u32,
unit: u8,
switch_to: u8
) -> ConvertingReceiver<()>
pub fn switch_socket_b(
&self,
address: u32,
unit: u8,
switch_to: u8
) -> ConvertingReceiver<()>
To switch a type B socket you have to give the address, unit and the state (on or off) you want to switch to.
To switch all devices with the same address use 255 for the unit.
A detailed description on how you can teach a socket the address and unit can be found here.
.. versionadded:: 2.0.1$nbsp;(Plugin)
Associated constants:
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_OFF
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_ON
sourcepub fn dim_socket_b(
&self,
address: u32,
unit: u8,
dim_value: u8
) -> ConvertingReceiver<()>
pub fn dim_socket_b(
&self,
address: u32,
unit: u8,
dim_value: u8
) -> ConvertingReceiver<()>
To control a type B dimmer you have to give the address, unit and the dim value you want to set the dimmer to.
A detailed description on how you can teach a dimmer the address and unit can be found here.
.. versionadded:: 2.0.1$nbsp;(Plugin)
sourcepub fn switch_socket_c(
&self,
system_code: char,
device_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
pub fn switch_socket_c(
&self,
system_code: char,
device_code: u8,
switch_to: u8
) -> ConvertingReceiver<()>
To switch a type C socket you have to give the system code, device code and the state (on or off) you want to switch to.
A detailed description on how you can figure out the system and device code can be found here.
.. versionadded:: 2.0.1$nbsp;(Plugin)
Associated constants:
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_OFF
- REMOTE_SWITCH_BRICKLET_SWITCH_TO_ON
sourcepub fn get_identity(&self) -> ConvertingReceiver<Identity>
pub fn get_identity(&self) -> ConvertingReceiver<Identity>
Returns the UID, the UID where the Bricklet is connected to, the position, the hardware and firmware version as well as the device identifier.
The position can be ‘a’, ‘b’, ‘c’, ‘d’, ‘e’, ‘f’, ‘g’ or ‘h’ (Bricklet Port). A Bricklet connected to an Isolator Bricklet is always at position ‘z’.
The device identifier numbers can be found here. |device_identifier_constant|